@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1997, 1998, 1999 Marius Vollmer
+ * Copyright (C) 1997, 1998 Marius Vollmer
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,15 +16,8 @@
  * the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <config.h>
 #include <libguile.h>
 #include <guile-gtk.h>
-#ifdef GTK_2_0
-#include <gtk-2.0/gdk/gdkprivate.h>
-#else
-#include <gdk/gdkprivate.h>
-#endif
-#include "gtk-threads.h"
 
 /* It is not strictly correct to have Gdk support functions here.  But
    as long as we do not want to have some SCM_PROCs for the (gdk gdk)
@@ -62,51 +55,6 @@ gtk_style_bg_gc (GtkStyle *style, GtkStateType state)
   return style->bg_gc[state];
 }
 
-GdkGC *
-gtk_style_light_gc (GtkStyle *style, GtkStateType state)
-{
-  if (style == NULL || state < 0 || state >= 5)
-    return NULL;
-
-  return style->light_gc[state];
-}
-
-GdkGC *
-gtk_style_dark_gc (GtkStyle *style, GtkStateType state)
-{
-  if (style == NULL || state < 0 || state >= 5)
-    return NULL;
-
-  return style->dark_gc[state];
-}
-
-GdkGC *
-gtk_style_mid_gc (GtkStyle *style, GtkStateType state)
-{
-  if (style == NULL || state < 0 || state >= 5)
-    return NULL;
-
-  return style->mid_gc[state];
-}
-
-GdkGC *
-gtk_style_text_gc (GtkStyle *style, GtkStateType state)
-{
-  if (style == NULL || state < 0 || state >= 5)
-    return NULL;
-
-  return style->text_gc[state];
-}
-
-GdkGC *
-gtk_style_base_gc (GtkStyle *style, GtkStateType state)
-{
-  if (style == NULL || state < 0 || state >= 5)
-    return NULL;
-
-  return style->base_gc[state];
-}
-
 /* Event destructuring */
 
 GdkEventType
@@ -127,18 +75,15 @@ gdk_event_send_event (GdkEvent *event)
   return event->any.send_event;
 }
 
-GdkRectangle
+GdkRectangle *
 gdk_event_area (GdkEvent *event)
 {
   switch (event->any.type)
     {
     case GDK_EXPOSE:
-      return event->expose.area;
+      return &event->expose.area;
     default:
-      {
-	GdkRectangle r = { 0, 0, 0, 0 };
-	return r;
-      }
+      return NULL;
     }
 }
 
@@ -192,9 +137,6 @@ gdk_event_x (GdkEvent *event)
     case GDK_BUTTON_PRESS:
     case GDK_BUTTON_RELEASE:
       return event->button.x;
-    case GDK_ENTER_NOTIFY:
-    case GDK_LEAVE_NOTIFY:
-      return event->crossing.x;
     default:
       return 0;
     }
@@ -210,15 +152,11 @@ gdk_event_y (GdkEvent *event)
     case GDK_BUTTON_PRESS:
     case GDK_BUTTON_RELEASE:
       return event->button.y;
-    case GDK_ENTER_NOTIFY:
-    case GDK_LEAVE_NOTIFY:
-      return event->crossing.y;
     default:
       return 0;
     }
 }
-#ifdef GTK_2_0
-#else
+
 gdouble
 gdk_event_pressure (GdkEvent *event)
 {
@@ -263,7 +201,7 @@ gdk_event_ytilt (GdkEvent *event)
       return 0;
     }
 }
-#endif
+
 gint
 gdk_event_button (GdkEvent *event)
 {
@@ -277,8 +215,8 @@ gdk_event_button (GdkEvent *event)
     }
 }
 
-guint
-gdk_event_state (GdkEvent *event)
+gboolean
+gdk_event_button_state (GdkEvent *event)
 {
   switch (event->any.type)
     {
@@ -287,9 +225,6 @@ gdk_event_state (GdkEvent *event)
     case GDK_BUTTON_PRESS:
     case GDK_BUTTON_RELEASE:
       return event->button.state;
-    case GDK_KEY_PRESS:
-    case GDK_KEY_RELEASE:
-      return event->key.state;
     default:
       return 0;
     }
@@ -306,7 +241,7 @@ gdk_event_is_hint (GdkEvent *event)
       return 0;
     }
 }
-#ifndef GTK_2_0
+
 GdkInputSource
 gdk_event_source (GdkEvent *event)
 {
@@ -322,7 +257,6 @@ gdk_event_source (GdkEvent *event)
     }
 }
 
-
 guint32
 gdk_event_deviceid (GdkEvent *event)
 {
@@ -337,7 +271,6 @@ gdk_event_deviceid (GdkEvent *event)
       return 0;
     }
 }
-#endif
 
 gdouble
 gdk_event_x_root (GdkEvent *event)
@@ -369,6 +302,19 @@ gdk_event_y_root (GdkEvent *event)
     }
 }
 
+gboolean
+gdk_event_key_state (GdkEvent *event)
+{
+  switch (event->any.type)
+    {
+    case GDK_KEY_PRESS:
+    case GDK_KEY_RELEASE:
+      return event->key.state;
+    default:
+      return 0;
+    }
+}
+
 guint
 gdk_event_keyval (GdkEvent *event)
 {
@@ -486,137 +432,6 @@ gdk_event_configure_height (GdkEvent *event)
     }
 }
 
-#ifndef GTK_2_0
-guint32
-gdk_get_leader_window_id ()
-{
-  return (guint32) gdk_leader_window;
-}
-
-guint32
-gdk_window_get_id (GdkWindow *window)
-{
-  return (guint32) ((GdkWindowPrivate*)window)->xwindow;
-}
-#endif
-
-SCM
-gdk_window_get_size_scm (GdkWindow *window)
-{
-  gint width;
-  gint height;
-  gdk_window_get_size (window, &width, &height);
-  return scm_cons (SCM_MAKINUM (width), SCM_MAKINUM (height));
-}
-
-SCM
-gdk_window_get_origin_scm (GdkWindow *window)
-{
-  gint x;
-  gint y;
-  gdk_window_get_origin (window, &x, &y);
-  return scm_cons (SCM_MAKINUM (x), SCM_MAKINUM (y));
-}
-
-void
-gdk_draw_text_scm (GdkDrawable  *drawable,
-		   GdkFont      *font,
-		   GdkGC	       *gc,
-		   gint		x,
-		   gint		y,
-		   const gchar  *text)
-{
-  gdk_draw_text (drawable, font, gc, x, y, text, strlen(text));
-}
-
-SCM_SYMBOL (sym_type, "-type");
-SCM_SYMBOL (sym_flags, "-flags");
-
-static SCM kw_type;
-static SCM kw_flags;
-
-extern sgtk_enum_info sgtk_gtk_arg_flags_info;
-
-SCM
-gtk_object_query_args_scm (GtkType type)
-{
-  guint nargs;
-  guint32 *arg_flags = NULL;
-  GtkArg *args;
-  SCM res = SCM_EOL, *restail = &res;
-  int i;
-
-  args = gtk_object_query_args (type, &arg_flags, &nargs);
-  if (args == NULL)
-    {
-      if (arg_flags)
-	g_free (arg_flags);
-      return SCM_BOOL_F;
-    }
-
-  for (i = 0; i < nargs; i++)
-    {
-      *restail =
-	scm_cons (scm_listify (scm_makfrom0str (args[i].name),
-			       kw_type,
-			       sgtk_type2scm (args[i].type),
-			       kw_flags,
-			       sgtk_flags2scm (arg_flags[i],
-					       &sgtk_gtk_arg_flags_info),
-			       SCM_UNDEFINED),
-		  SCM_EOL);
-      restail = SCM_CDRLOC(*restail);
-    }
-
-  g_free (args);
-  g_free (arg_flags);
-
-  return res;
-}
-
-int
-gtk_editable_insert_text_scm (GtkEditable *editable,
-			      gchar       *text,
-			      int          position)
-{
-  gtk_editable_insert_text (editable, text, strlen (text), &position);
-  return position;
-}
-
-int gtk_widget_allocation_width_scm (GtkWidget *widget)
-{
-  return widget->allocation.width;
-}
-
-int gtk_widget_allocation_height_scm (GtkWidget *widget)
-{
-  return widget->allocation.height;
-}
-
-int gtk_widget_allocation_x_scm (GtkWidget *widget)
-{
-  return widget->allocation.x;
-}
-
-int gtk_widget_allocation_y_scm (GtkWidget *widget)
-{
-  return widget->allocation.y;
-}
-
-void* g_timer_fake_copy (void* ptr)
-{
-  return ptr;
-}
-
-void *gtk_no_copy (void *ptr)
-{
-  return NULL;
-}
-
-void gtk_no_free (void *ptr)
-{
-}
-
 
 
 /* These SCM_PROCs are here to have them initialized in
@@ -638,8 +453,6 @@ SCM_PROC (s_gtk_widget_new, "gtk-widget-new", 1, 0, 1, sgtk_gtk_object_new);
 SCM_PROC (s_gtk_widget_set, "gtk-widget-set", 1, 0, 1, sgtk_gtk_object_set);
 SCM_PROC (s_gtk_widget_get, "gtk-widget-get", 2, 0, 0, sgtk_gtk_object_get);
 
-SCM_PROC (s_gtk_threads_update, "gtk-threads-update", 0, 0, 0, sgtk_threads_update);
-
 void
 sgtk_init_gtk_support ()
 {
@@ -648,7 +461,4 @@ sgtk_init_gtk_support ()
 #include "gtk-support.x"
 #endif /* MKDEP */
 #endif /* SCM_MAGIC_SNARFER */
-
-  kw_type = scm_make_keyword_from_dash_symbol (sym_type);
-  kw_flags = scm_make_keyword_from_dash_symbol (sym_flags);
 }
